@@ -14,7 +14,7 @@ class OptionClass:
 	width=400
 	height=400
 	frontend="DefaultVisualization"
-	ensemble="none"
+	ensemble=None
 	no_fluidsynth=False
 	verbose=True
 	meter = (4,4)
